/**
 * Simple Jquery Form Builder (SJFB)
 * Copyright (c) 2015 Brandon Hoover, Hoover Web Development LLC (http://bhoover.com)
 * http://bhoover.com/simple-jquery-form-builder/
 * SJFB may be freely distributed under the included MIT license (license.txt).
 */

$(function()
{
    //If loading a saved form from your database, put the ID here. Example id is "1".
    var formID = '1';

    //Adds new field with animation
    $("#add-field a").click(function(event) 
	{
        event.preventDefault();
		$('#theSub').show();
        $(addField($(this).data('type'))).appendTo('#form-fields').hide().slideDown('fast');
        $('#form-fields').sortable();
    });

    //Removes fields and choices with animation
    $("#sjfb").on("click", ".delete", function() 
	{
		var $this = $(this);
		 
		swal({
			title: 'Supprimer le champ ?',			
			type: 'warning',
			showCancelButton: true,
			reverseButtons: true,
			confirmButtonColor: '#3085d6',
			cancelButtonColor: '#d33',
			confirmButtonText: 'Oui, supprimer!',
			cancelButtonText: 'Annuler'
		}).then(function () 
		{           
            $this.parent().slideUp( "slow", function() {
                $this.parent().remove()
            });
        });
    });

    //Makes fields required
    $("#sjfb").on("click", ".toggle-required", function() {
        requiredField($(this));
    });

    //Makes choices selected
    $("#sjfb").on("click", ".toggle-selected", function() {
        selectedChoice($(this));
    });

    //Adds new choice to field with animation
    $("#sjfb").on("click", ".add-choice", function() {
        $(addChoice()).appendTo($(this).prev()).hide().slideDown('fast');
        $('.choices ul').sortable();
    });

    //Saving form
    $("#sjfb").submit(function(event) 
	{
        event.preventDefault();

        //Loop through fields and save field data to array
        var fields = [];

        $('.field').each(function() {

            var $this = $(this);

            //field type
            var fieldType = $this.data('type');

            //field label
            var fieldLabel = $this.find('.field-label').val();
			
            //field name            
            var fieldName = $this.find('.field-label').attr('name');
			
            //field default            
            var fieldDefault = $this.find('.field-label').attr('data-default');				

            //field required
            var fieldReq = $this.hasClass('required') ? 1 : 0;

            //check if this field has choices
            if($this.find('.choices li').length >= 1) 
			{
                var choices = [];
				var iVal	= 0;

                $this.find('.choices li').each(function() 
				{
                    var $thisChoice = $(this);

                    //choice label
                    var choiceLabel = $thisChoice.find('.choice-label').val();

                    //choice selected
                    var choiceSel = $thisChoice.hasClass('selected') ? 1 : 0;

                    choices.push({
                        label: choiceLabel,
                        sel: choiceSel,
						val: iVal
                    });

					iVal++;
                });
            }

            fields.push({
                type: fieldType,
                label: fieldLabel,
                req: fieldReq,
                choices: choices,
				name: fieldName,
				default: fieldDefault
            });

        });

        var frontEndFormHTML = '';

        //Save form to database
        //Demo doesn't actually save. Download project files for save
        var data = 'typeAjx=26&data=' + JSON.stringify([{"name":"formID","value":formID},{"name":"formFields","value":fields}]);
		
        $.ajax(
		{
            type		: 'POST',
            url			: '/scm/ajax/global.ajx.php',
            data		: data,
            dataType	: 'json',
            success: function (msg) 
			{
				swal({
					title: 'Bravo!', 
					text: data['reponse'], 
					type: 'success'
				}).then(function(){ location.href = '/scm/'+langue+'/membres-params/'; });
            }
        });
    });

    //load saved form
    loadForm(formID);

});

//Add field to builder
function addField(fieldType) 
{
    var hasRequired, hasChoices;
    var includeRequiredHTML = '';
    var includeChoicesHTML = '';

    switch (fieldType) 
	{
        case 'text':
            hasRequired = true;
            hasChoices = false;
            break;
        case 'file':
            hasRequired = true;
            hasChoices = false;
            break;		
        case 'textarea':
            hasRequired = true;
            hasChoices = false;
            break;
        case 'select':
            hasRequired = true;
            hasChoices = true;
            break;
        case 'radio':
            hasRequired = true;
            hasChoices = true;
            break;
        case 'checkbox':
            hasRequired = false;
            hasChoices = true;
            break;
        case 'agree':
            //required "agree to terms" checkbox
            hasRequired = false;
            hasChoices = false;
            break;
    }

    if (hasRequired) 
	{
        includeRequiredHTML = '' +
            '<label>Obligatoire ? ' +
            '<input class="toggle-required" type="checkbox">' +
            '</label>'
    }

    if (hasChoices) 
	{
        includeChoicesHTML = '' +
            '<div class="choices">' +
            '<ul></ul>' +
            '<button type="button" class="add-choice btnStd">Ajouter un choix</button>' +
            '</div>'
    }
	
	var uniqueID = Math.floor(Math.random()*999999)+1;

    return '' +
        '<div class="field" data-type="' + fieldType + '">' +
        '<button type="button" class="delete">X</button>' +
        '<h3>' + fieldType + '</h3>' +
        '<label>Nom : ' +
        '<input type="text" class="field-label" name="sjfb-'+uniqueID+'">' +
        '</label>' +
        includeRequiredHTML +
        includeChoicesHTML +
        '</div>'
}

//Make builder field required
function requiredField($this) {
    if (!$this.parents('.field').hasClass('required')) {
        //Field required
        $this.parents('.field').addClass('required');
        $this.attr('checked','checked');
    } else {
        //Field not required
        $this.parents('.field').removeClass('required');
        $this.removeAttr('checked');
    }
}

function selectedChoice($this) {
    if (! $this.parents('li').hasClass('selected')) {

        //Only checkboxes can have more than one item selected at a time
        //If this is not a checkbox group, unselect the choices before selecting
        if ($this.parents('.field').data('type') != 'checkbox') {
            $this.parents('.choices').find('li').removeClass('selected');
            $this.parents('.choices').find('.toggle-selected').not($this).removeAttr('checked');
        }

        //Make selected
        $this.parents('li').addClass('selected');
        $this.attr('checked','checked');

    } else {

        //Unselect
        $this.parents('li').removeClass('selected');
        $this.removeAttr('checked');

    }
}

//Builder HTML for select, radio, and checkbox choices
function addChoice() {
    return '' +
        '<li>' +
        '<label>Choix : ' +
        '<input type="text" class="choice-label">' +
        '</label>' +
        '<label>Sélectionné ? ' +
        '<input class="toggle-selected" type="checkbox">' +
        '</label>' +
        '<button type="button" class="delete">X</button>' +
        '</li>'
}

//Loads a saved form from your database into the builder
function loadForm(formID) 
{
    $.getJSON('/scm/ajax/sjfb-load.php?form_id=' + formID, function(data) 
	{
        if(data) 
		{
			var l = 0;
			
            //go through each saved field object and render the builder
            $.each( data, function( k, v ) 
			{
                //Add the field
                $(addField(v['type'])).appendTo('#form-fields').hide().slideDown('fast');
                var $currentField = $('#form-fields .field').last();

                //Add the label
                $currentField.find('.field-label').val(v['label']);
				
				//Add the name
				$currentField.find('.field-label').attr('name',v['name']);
				
				//Add default
				v['default'] == 1 ?
				$currentField.find('.field-label').attr('data-default',v['default']) : '';
				
				//Delete the adhesion
				$currentField.find('input[name="adhesion"]').parents('.field').remove();	

                //Is it required?
                if (v['req']) 
				{
                    requiredField($currentField.find('.toggle-required'));
                }

                //Any choices?
                if (v['choices']) 
				{
                    $.each( v['choices'], function( k, v ) {
                        //add the choices
                        $currentField.find('.choices ul').append(addChoice());

                        //Add the label
                        $currentField.find('.choice-label').last().val(v['label']);

                        //Is it selected?
                        if (v['sel']) {
                            selectedChoice($currentField.find('.toggle-selected').last());
                        }
                    });
                }
				
				//Delete Cross for default
				v['default'] == 1 ?
				$currentField.find('.field-label').parents('.field').find('button').remove() : '';				
				
				l++;
            });

			if(l > 0){ $('#theSub').show(); }
            $('#form-fields').sortable();
            $('.choices ul').sortable();
        }
    });
}